***************
YAML Parameters
***************

Configurable model parameters are listed in the
:doc:`../reference/model/yaml_defaults`.
Links to the API documentation for different types of YAML Parameters are
provided below. The YAML parameters are sorted by "type", for example,
:ref:`model-domain-parameters` are those parameters which control the
definition of the pyDeltaRCM model domain.

Model Settings
==============

:attr:`pyDeltaRCM.model.DeltaModel.out_dir`

:attr:`pyDeltaRCM.model.DeltaModel.verbose`

:attr:`pyDeltaRCM.model.DeltaModel.seed`


.. _model-domain-parameters:

Model Domain Parameters
=======================

:attr:`pyDeltaRCM.model.DeltaModel.Length`

:attr:`pyDeltaRCM.model.DeltaModel.Width`

:attr:`pyDeltaRCM.model.DeltaModel.dx`

:attr:`pyDeltaRCM.model.DeltaModel.L0_meters`

:attr:`pyDeltaRCM.model.DeltaModel.S0`

:attr:`pyDeltaRCM.model.DeltaModel.itermax`

:attr:`pyDeltaRCM.model.DeltaModel.Np_water`

:attr:`pyDeltaRCM.model.DeltaModel.u0`

:attr:`pyDeltaRCM.model.DeltaModel.N0_meters`

:attr:`pyDeltaRCM.model.DeltaModel.h0`

:attr:`pyDeltaRCM.model.DeltaModel.hb`

:attr:`pyDeltaRCM.model.DeltaModel.H_SL`

:attr:`pyDeltaRCM.model.DeltaModel.SLR`

:attr:`pyDeltaRCM.model.DeltaModel.Np_sed`

:attr:`pyDeltaRCM.model.DeltaModel.f_bedload`

:attr:`pyDeltaRCM.model.DeltaModel.active_layer_thickness`

:attr:`pyDeltaRCM.model.DeltaModel.C0_percent`

:attr:`pyDeltaRCM.model.DeltaModel.Csmooth`

:attr:`pyDeltaRCM.model.DeltaModel.toggle_subsidence`

:attr:`pyDeltaRCM.model.DeltaModel.subsidence_rate`

:attr:`pyDeltaRCM.model.DeltaModel.start_subsidence`


Output Settings
===============

:attr:`pyDeltaRCM.model.DeltaModel.save_eta_figs`

:attr:`pyDeltaRCM.model.DeltaModel.save_stage_figs`

:attr:`pyDeltaRCM.model.DeltaModel.save_depth_figs`

:attr:`pyDeltaRCM.model.DeltaModel.save_discharge_figs`

:attr:`pyDeltaRCM.model.DeltaModel.save_velocity_figs`

:attr:`pyDeltaRCM.model.DeltaModel.save_sedflux_figs`

:attr:`pyDeltaRCM.model.DeltaModel.save_sandfrac_figs`

:attr:`pyDeltaRCM.model.DeltaModel.save_figs_sequential`

:attr:`pyDeltaRCM.model.DeltaModel.save_eta_grids`

:attr:`pyDeltaRCM.model.DeltaModel.save_stage_grids`

:attr:`pyDeltaRCM.model.DeltaModel.save_depth_grids`

:attr:`pyDeltaRCM.model.DeltaModel.save_discharge_grids`

:attr:`pyDeltaRCM.model.DeltaModel.save_velocity_grids`

:attr:`pyDeltaRCM.model.DeltaModel.save_sedflux_grids`

:attr:`pyDeltaRCM.model.DeltaModel.save_sandfrac_grids`

:attr:`pyDeltaRCM.model.DeltaModel.save_discharge_components`

:attr:`pyDeltaRCM.model.DeltaModel.save_velocity_components`

:attr:`pyDeltaRCM.model.DeltaModel.save_dt`

:attr:`pyDeltaRCM.model.DeltaModel.checkpoint_dt`

:attr:`pyDeltaRCM.model.DeltaModel.save_checkpoint`

:attr:`pyDeltaRCM.model.DeltaModel.resume_checkpoint`

:attr:`pyDeltaRCM.model.DeltaModel.clobber_netcdf`

:attr:`pyDeltaRCM.model.DeltaModel.legacy_netcdf`


Reduced-Complexity Routing Parameters
=====================================

:attr:`pyDeltaRCM.model.DeltaModel.omega_sfc`

:attr:`pyDeltaRCM.model.DeltaModel.omega_flow`

:attr:`pyDeltaRCM.model.DeltaModel.Nsmooth`

:attr:`pyDeltaRCM.model.DeltaModel.theta_water`

:attr:`pyDeltaRCM.model.DeltaModel.coeff_theta_sand`

:attr:`pyDeltaRCM.model.DeltaModel.coeff_theta_mud`

:attr:`pyDeltaRCM.model.DeltaModel.beta`

:attr:`pyDeltaRCM.model.DeltaModel.sed_lag`

:attr:`pyDeltaRCM.model.DeltaModel.coeff_U_dep_mud`

:attr:`pyDeltaRCM.model.DeltaModel.coeff_U_ero_mud`

:attr:`pyDeltaRCM.model.DeltaModel.coeff_U_ero_sand`

:attr:`pyDeltaRCM.model.DeltaModel.alpha`

:attr:`pyDeltaRCM.model.DeltaModel.stepmax`
